@@ -1,3 +1,4 @@
+const sha1 = require('js-sha1');
 exports.render = function (req, res) {
     res.render('index', {
         'title': "Hello",
@@ -7,13 +8,15 @@ exports.render = function (req, res) {
 }
 exports.db = function (req, res) {
     var r = req.r;
+   console.log(req.x());
+    //console.log(r);
     var x = function (data) {
         res.json(data);
     }
    // console.log("xxx");
     //try {
-        r.db("oauth")
-            .table("users")
+       // r.db("oauth")
+            r.table("users")
             .run()
             .then(function (data) {
                 x(data);
@@ -120,4 +123,10 @@ exports.pusher = function (req, res) {
         console.log(err);
         res.end("");
     })
-};
\ No newline at end of file
+};
+
+ exports.sha1= function(req, res) {
+        var password = req.query.password;
+        var data = sha1(password);
+        res.send(data);
+    }
\ No newline at end of file
